@@ -128,7 +128,7 @@ class CodonDictionaries():
                           'C':['TGC', 'TGT','UGC','UGU'],
                           'Q':['CAA', 'CAG'],
                           'E':['GAA', 'GAG'],
-                          'G':['GGT', 'GGC', 'GGA', 'GGC','GGU'],
+                          'G':['GGT', 'GGC', 'GGA', 'GGG','GGU'],
                           'H':['CAC', 'CAT','CAU'],
                           'I':['ATT', 'ATC', 'ATA','AUU','AUC','AUA'],
                           'L':['CTA', 'CTC', 'CTG', 'CTT', 'TTA', 'TTG','CUA', 'CUC', 'CUG', 'CUU', 'UUA', 'UUG'],
@@ -136,7 +136,7 @@ class CodonDictionaries():
                           'M':['ATG','AUG'],
                           'F':['TTC', 'TTT','UUC','UUU'],
                           'P':['CCT', 'CCC', 'CCG', 'CCA','CCU'],
-                          'S':['TCA', 'TCC', 'TCG', 'TCT','AGC','AGT','UCA','UCC','UCG'],
+                          'S':['TCA', 'TCC', 'TCG', 'TCT','AGC','AGT',  'UCA','UCC','UCG', 'UCU','AGU'],
                           'T':['ACA', 'ACC', 'ACG', 'ACT','ACU'],
                           'W':['TGG','UGG'],
                           'Y':['TAT', 'TAC','UAC','UAU'],
