@@ -18,8 +18,6 @@ import time
 
 import os
 
-
-
 ## Search locally for ssa_cpp
 path_to_cpp = ''
 path_to_gen = ''
@@ -385,14 +383,17 @@ class TranslationSolvers():
 
             k_trna = np.array(list(CodonDictionaries().strGeneCopy_single.values()))
         
-        print(k_trna)
+        
         if not provided_probe:
             if provided_protein:
                 probe_vec = self.protein.probe_vec.astype(np.int32)
                 probe_loc = self.protein.probe_loc.astype(np.int32)
             else:
-                print("no provided probe vector, please set the solver.protein with a protein object or provide a probe vector")
-                raise 
+                try:
+                    num = int("string")
+                except ValueError:
+                    print("no provided probe vector, please set the solver.protein with a protein object or provide a probe vector")
+               
         else:
             probe_vec = probe_vec
             
@@ -917,7 +918,7 @@ class TranslationSolvers():
         for i in range(n_traj):
             soln = all_results[i, :].reshape((N_rib, len(t)))
        
-
+            
             validind = np.where(np.sum(soln,axis=1)!=0)[0]
             
 
@@ -1518,8 +1519,16 @@ class TranslationSolvers():
         validind = 0
         riblocs = []
         for i in range(len(all_rib_loc)):
-            if np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1] > validind:
-                validind = np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1]
+            try: 
+                
+        
+                if np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1] > validind:
+                    
+                    validind = np.where(np.sum(all_rib_loc[i].T,axis=1)!=0)[0][-1]
+                    
+                        #there was a blank 
+            except:
+                pass
                 
                 
         all_rib_loc = all_rib_loc[:,:,:validind]
